@@ -1,5 +1,11 @@
 #!/usr/bin/env python
 
+# This is required to create a namespace package.
+# A namespace package allows programs to be located in different directories or
+# eggs.
+
+__import__('pkg_resources').declare_namespace(__name__)
+
 from pyhmsa.spec.condition.acquisition import *
 from pyhmsa.spec.condition.calibration import *
 from pyhmsa.spec.condition.composition import *
